# v0.1.25 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Break up workflows and prevent secrets from not passing ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.24 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Update test requirements ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.23 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- New publish step ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.22 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Manually trigger publish ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.21 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Use PyPI token ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.20 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Update publish trigger ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.19 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Fix CI workflow ([@alexchristy](https://github.com/alexchristy))
- Fix publish trigger ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.18 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Update publish.yml ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.17 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Update publish workflow ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.16 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Update publish workflows ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.15 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Update pr label check workflow ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.14 (Tue Nov 26 2024)

#### ⚠️ Pushed to `main`

- Update release workflow ([@alexchristy](https://github.com/alexchristy))
- Update release.yml ([@alexchristy](https://github.com/alexchristy))
- Update release workflows ([@alexchristy](https://github.com/alexchristy))
- Update release.yml to use scoped token ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.13 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Update workflows ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.12 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Remove publish workflow call ([@alexchristy](https://github.com/alexchristy))
- Switch to release triggered publishing ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.11 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Rename workflow ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.10 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Validate hatch version ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.9 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Update publish.yml ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.8 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Update publish.yml ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.7 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Update workflows to publish properly ([@alexchristy](https://github.com/alexchristy))
- Rename github token value in release.yml ([@alexchristy](https://github.com/alexchristy))
- Update workflows to use GitHub vars and secrets ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.6 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Update workflows to publish to PyPI ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.5 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Fix _version.py ignore ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.4 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Remove _version.py from git ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.3 (Mon Nov 25 2024)

#### 🐛 Bug Fix

- Pypi pub [#4](https://github.com/alexchristy/PyOPN/pull/4) ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.2 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Link to actions in README CI badge ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.1 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Add CI badge to README ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.1.0 (Mon Nov 25 2024)

#### 🚀 Enhancement

- Added Dev Tools and Workflows [#3](https://github.com/alexchristy/PyOPN/pull/3) ([@alexchristy](https://github.com/alexchristy))

#### ⚠️ Pushed to `main`

- Add .autorc back ([@alexchristy](https://github.com/alexchristy))
- Make release.yml callable ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.0.2 (Mon Nov 25 2024)

#### ⚠️ Pushed to `main`

- Update auto configuration ([@alexchristy](https://github.com/alexchristy))

#### Authors: 1

- Alex Christy ([@alexchristy](https://github.com/alexchristy))

---

# v0.0.1 (Mon Nov 25 2024)

#### 🐛 Bug Fix

- Add Kea Controller [#2](https://github.com/alexchristy/PyOPN/pull/2) ([@alexchristy](https://github.com/alexchristy))
- Dhcpv4 [#1](https://github.com/alexchristy/PyOPN/pull/1) ([@alexchristy](https://github.com/alexchristy))

#### ⚠️ Pushed to `main`

- Add auto release workflow ([@alexchristy](https://github.com/alexchristy))
- Update README.md fix grammar ([@alexchristy](https://github.com/alexchristy))
- Update README.md to fix typo ([@alexchristy](https://github.com/alexchristy))
- Update CONTRIBUTING.md to add PR note ([@alexchristy](https://github.com/alexchristy))
- Update README ([@alexchristy](https://github.com/alexchristy))
- Add new CONTRIBUTING.md ([@alexchristy](https://github.com/alexchristy))
- Remove unimplemented diagnostic API module ([@alexchristy](https://github.com/alexchristy))
- Delete extra parameter in docstring of kea/dhcpv4/set_reservation ([@alexchristy](https://github.com/alexchristy))
- Rename package in copywrite ([@alexchristy](https://github.com/alexchristy))
- Remove untested/undocumented endpoints ([@alexchristy](https://github.com/alexchristy))
- Delete old project docs ([@alexchristy](https://github.com/alexchristy))
- Add extra tests for file upload client methods ([@alexchristy](https://github.com/alexchristy))
- Remove uneeded import ([@alexchristy](https://github.com/alexchristy))
- Cleanup ([@alexchristy](https://github.com/alexchristy))
- Rename folder from pyopnsense to pyopn ([@alexchristy](https://github.com/alexchristy))
- Add type hints for IDE auto completion ([@alexchristy](https://github.com/alexchristy))
- Wrap old class in API object ([@alexchristy](https://github.com/alexchristy))
- Merge branch 'tofuSCHNITZEL-patch-1' ([@tofuSCHNITZEL](https://github.com/tofuSCHNITZEL))
- fixed tests ([@tofuSCHNITZEL](https://github.com/tofuSCHNITZEL))
- Change client to accept json data directly ([@tofuSCHNITZEL](https://github.com/tofuSCHNITZEL))
- Suppress error message "InsecureRequestWarning: Unverified HTTPS request is being made" if verify_cert is False ([@jaydeethree](https://github.com/jaydeethree))
- Correct front page example and clean up SSL text. ([@fotonick](https://github.com/fotonick))
- Fix test_get_success ([@mtreinish](https://github.com/mtreinish))
- Allow configuring the client timeout, closes #15 (adam.mckee@tanium.com)
- Update pyopnsense/firewall.py ([@patmann03](https://github.com/patmann03))
- add gpl license comment ([@patmann03](https://github.com/patmann03))
- revert back to f strings python 3.5 not supported (Patrick.Carr@fresenius-kabi.com)
- update for python 3.5 (Patrick.Carr@fresenius-kabi.com)
- add firewall client (Patrick.Carr@fresenius-kabi.com)
- Merge branch 'main' into master ([@monstermichl](https://github.com/monstermichl))
- Fix BackupClient download documentation ([@monstermichl](https://github.com/monstermichl))
- Update supported python versions and CI config ([@mtreinish](https://github.com/mtreinish))
- Add backup endpoint functionality (os-api-backup OPNsense plugin required) ([@monstermichl](https://github.com/monstermichl))
- Add a license statement ([@definitio](https://github.com/definitio))
- Add official support for Python 3.8 and Python 3.9 ([@mtreinish](https://github.com/mtreinish))
- Fix test jobs ([@mtreinish](https://github.com/mtreinish))
- Add docs for gateway client ([@definitio](https://github.com/definitio))
- Add gateway client ([@definitio](https://github.com/definitio))
- Add missing newline ([@mtreinish](https://github.com/mtreinish))
- Merge branch 'master' into timeout ([@fabaff](https://github.com/fabaff))
- Add support for python 3.7 ([@mtreinish](https://github.com/mtreinish))
- Add timeout ([@fabaff](https://github.com/fabaff))
- Remove tests ([@fabaff](https://github.com/fabaff))
- Add timeout and remove HTTP verbs ([@fabaff](https://github.com/fabaff))
- Update docstrings ([@fabaff](https://github.com/fabaff))
- Make sure that the keys are strings ([@fabaff](https://github.com/fabaff))
- Update/fix example ([@fabaff](https://github.com/fabaff))
- Add api docs for diagnostics clients ([@mtreinish](https://github.com/mtreinish))
- Add a link to the API ref docs in the README ([@mtreinish](https://github.com/mtreinish))
- Start to flush out the documentation ([@mtreinish](https://github.com/mtreinish))
- Add a method to the issue a firmware ugprade ([@mtreinish](https://github.com/mtreinish))
- Add docstrings to firmware.py ([@mtreinish](https://github.com/mtreinish))
- Use coveralls for coverage tracking ([@mtreinish](https://github.com/mtreinish))
- Add missing unit tests for HTTP delete ([@mtreinish](https://github.com/mtreinish))
- Fix coverage tox job definition ([@mtreinish](https://github.com/mtreinish))
- Add unit tests for all HTTP methods ([@mtreinish](https://github.com/mtreinish))
- Expand the README ([@mtreinish](https://github.com/mtreinish))
- Flush out diagnostics module ([@mtreinish](https://github.com/mtreinish))
- Fix docs builds ([@mtreinish](https://github.com/mtreinish))
- Add netflow diagnostics client ([@mtreinish](https://github.com/mtreinish))
- Expand base client to support most HTTP methods ([@mtreinish](https://github.com/mtreinish))
- Add travis config ([@mtreinish](https://github.com/mtreinish))
- Add unit tests ([@mtreinish](https://github.com/mtreinish))
- Remove py3.4 trove classifier ([@mtreinish](https://github.com/mtreinish))
- Fix pep8 issues ([@mtreinish](https://github.com/mtreinish))
- Remove stray debug print ([@mtreinish](https://github.com/mtreinish))
- Fix copyright headers ([@mtreinish](https://github.com/mtreinish))
- Add basic docs scaffolding ([@mtreinish](https://github.com/mtreinish))
- Initial commit ([@mtreinish](https://github.com/mtreinish))

#### Authors: 11

- [@definitio](https://github.com/definitio)
- [@jaydeethree](https://github.com/jaydeethree)
- [@patmann03](https://github.com/patmann03)
- Adam McKee (adam.mckee@tanium.com)
- Alex Christy ([@alexchristy](https://github.com/alexchristy))
- Fabian Affolter ([@fabaff](https://github.com/fabaff))
- Matthew Treinish ([@mtreinish](https://github.com/mtreinish))
- Michel ([@monstermichl](https://github.com/monstermichl))
- Nickolas Fotopoulos ([@fotonick](https://github.com/fotonick))
- Patrick Carr (Patrick.Carr@fresenius-kabi.com)
- Tobias Perschon ([@tofuSCHNITZEL](https://github.com/tofuSCHNITZEL))
